package nadrzniSystem

  package parts
     connector pqcon
      Real p(unit="Pa");
      flow Real q(unit="m3/s");//, displayUnit="l/min");
       annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
                 {100,100}}), graphics={Polygon(
               points={{-80,38},{-80,60},{-68,60},{-66,78},{-42,76},{-30,96},{-16,86},
                   {-4,100},{6,86},{26,98},{32,82},{52,96},{52,72},{76,78},{72,54},{92,
                   48},{86,28},{102,8},{90,0},{108,-10},{88,-20},{98,-40},{80,-42},{82,
                   -76},{60,-70},{58,-92},{38,-84},{36,-100},{18,-90},{8,-106},{0,-92},
                   {-18,-106},{-24,-88},{-46,-104},{-46,-82},{-64,-100},{-62,-72},{-80,
                   -84},{-70,-62},{-92,-62},{-82,-42},{-100,-32},{-90,-16},{-104,-2},
                   {-88,14},{-98,32},{-82,38},{-80,38}},
               smooth=Smooth.None,
               fillColor={255,170,170},
               fillPattern=FillPattern.Solid,
               pattern=LinePattern.None)}));
     end pqcon;

  model nadrz

    pqcon pqcon1 annotation (Placement(transformation(extent={{-10,-100},{10,-80}}),
          iconTransformation(extent={{-10,-100},{10,-80}})));
    parameter Real S = 0.1;
    parameter Real Ro = 1e3;
    parameter Real g(unit = "m.s-2") = 10;
    parameter Real pocVyska( unit = "m")= 10;
    Real V(unit="m3");
    // pozor, neni-li fixed = true, pak Dymola vezme default hodnotu pro V = 0. Pravdepodobne bug.
    Real h(start = pocVyska, fixed=true, unit="m");
  initial equation
  //  h = pocVyska;
  equation
    S*h = V;
    der(V)= pqcon1.q;
    pqcon1.p = h*Ro*g;
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
              {100,100}}), graphics={
          Polygon(
            points={{-72,86},{-72,-100},{68,-100},{68,86},{86,98},{-84,98},{-72,86}},
            pattern=LinePattern.None,
            smooth=Smooth.None,
            fillColor={85,255,85},
            fillPattern=FillPattern.Solid,
            lineColor={0,0,0}),
          Rectangle(
            extent={{-72,40},{68,-22}},
            lineColor={0,0,0},
            lineThickness=0.5,
            fillColor={215,215,215},
            fillPattern=FillPattern.Solid),
          Text(
            extent={{-72,-52},{68,10}},
            lineColor={0,0,0},
            lineThickness=0.5,
            fillColor={215,215,215},
            fillPattern=FillPattern.Solid,
            textString="PET
")}));

  end nadrz;

  model odpornik

      pqcon pqcon1
      annotation (Placement(transformation(extent={{-60,-10},{-40,10}}),
          iconTransformation(extent={{-60,-10},{-40,10}})));
      pqcon pqcon2
                 annotation (Placement(transformation(extent={{78,-14},{98,6}})));
      parameter Real R;
      Real dp;
  equation
      dp = pqcon1.p - pqcon2.p;
      dp = R*pqcon1.q;

      pqcon1.q + pqcon2.q = 0;
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
              {100,100}}), graphics={
          Ellipse(
            extent={{32,100},{78,-104}},
            lineColor={0,0,0},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid,
            lineThickness=0.5),
          Rectangle(
            extent={{-38,100},{54,-104}},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid,
            pattern=LinePattern.None),
          Line(
            points={{-36,100},{56,100}},
            smooth=Smooth.None,
            color={0,0,0},
            thickness=0.5),
          Line(
            points={{-36,-104},{58,-104}},
            smooth=Smooth.None,
            color={0,0,0},
            thickness=0.5),
          Ellipse(
            extent={{-58,100},{-12,-104}},
            lineColor={0,0,0},
            fillColor={95,95,95},
            fillPattern=FillPattern.Solid,
            lineThickness=0.5)}));
  end odpornik;

  model tlakoZdroj

    pqcon pqcon1
      annotation (Placement(transformation(extent={{-40,-24},{-20,-2}}),
            iconTransformation(extent={{-40,-24},{-20,-2}})));
  parameter Real p;
  equation
    pqcon1.p = p;
      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{
                -100,-100},{100,100}}), graphics={
            Ellipse(
              extent={{14,86},{100,52}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Polygon(
              points={{-94,-22},{50,-22},{24,-72},{24,-108},{-64,-108},{-94,-22}},

              lineColor={0,0,0},
              lineThickness=0.5,
              smooth=Smooth.None,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Ellipse(
              extent={{-110,12},{44,-38}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{0,68},{26,62}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Ellipse(
              extent={{-76,-2},{16,-24}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Rectangle(
              extent={{14,68},{100,-38}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid),
            Text(
              extent={{-70,-104},{20,-48}},
              lineColor={0,0,0},
              lineThickness=0.5,
              fillColor={215,215,215},
              fillPattern=FillPattern.Solid,
              textString="P = %p")}));
  end tlakoZdroj;
  end parts;

  model System "Model celkoveho systemu"

    parts.nadrz nadrz(pocVyska=1)
      annotation (Placement(transformation(extent={{-96,10},{-60,84}})));
    parts.odpornik odpornik(R=1e4, L=1)
      annotation (Placement(transformation(extent={{-46,-18},{6,40}})));
    parts.tlakoZdroj tlakoZdroj(p=0)
      annotation (Placement(transformation(extent={{36,-96},{96,-26}})));
  equation
    connect(nadrz.pqcon1, odpornik.pqcon1) annotation (Line(
        points={{-78,13.7},{-63.6,13.7},{-63.6,11},{-33,11}},
        color={0,0,0},
        smooth=Smooth.None));
    connect(odpornik.pqcon2, tlakoZdroj.pqcon1) annotation (Line(
        points={{2.88,9.84},{14.4,9.84},{14.4,-65.55},{57,-65.55}},
        color={0,0,0},
        smooth=Smooth.None));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}),      graphics));
  end System;
  annotation (uses(Modelica(version="3.2")));
end nadrzniSystem;
